/* digest.c
 *
 * Copyright (c) 2009 Jonathan Dieter <jdieter@gmail.com>
 *
 * This program is licensed under the BSD license, read LICENSE.BSD
 * for further information
 */

#include <stdlib.h>
#include <stdio.h>

#include "md5.h"
#include "sha256.h"

void
digest_init(void *cntx, unsigned int digestalgo)
{
  if (digestalgo == 1)
    rpmMD5Init((MD5_CTX*)cntx);
  else if (digestalgo == 8)
    SHA256_init((SHA256_ctx*)cntx);
  else
    {
      fprintf(stderr, "Unknown digest type: %i\n", digestalgo);
      exit(1);
    }
}

void
digest_update(void *cntx, unsigned int digestalgo, unsigned char const *buf, unsigned len)
{
  if (digestalgo == 1)
    rpmMD5Update((MD5_CTX*)cntx, buf, len);
  else if (digestalgo == 8)
    SHA256_update((SHA256_ctx*)cntx, buf, len);
  else
    {
      fprintf(stderr, "Unknown digest type: %i\n", digestalgo);
      exit(1);
    }
}

void
digest_update32(void *cntx, unsigned int digestalgo, unsigned int i)
{
  if (digestalgo == 1)
    rpmMD5Update32((MD5_CTX*)cntx, i);
  else if (digestalgo == 8)
    SHA256_update32((SHA256_ctx*)cntx, i);
  else
    {
      fprintf(stderr, "Uknown digest type: %i\n", digestalgo);
      exit(1);
    }
}

void
digest_final(void *cntx, unsigned int digestalgo, unsigned char *digest)
{
  if (digestalgo == 1)
    rpmMD5Final(digest, (MD5_CTX*)cntx);
  else if (digestalgo == 8)
    {
      SHA256_final((SHA256_ctx*)cntx);
      SHA256_digest((SHA256_ctx*)cntx, digest);
    }
  else
    {
      fprintf(stderr, "Uknown digest type: %i\n", digestalgo);
      exit(1);
    }
}


